Changelog 
==========

0.1.4 (2020-11-14)
------------------

- added docs
- Deprecate ``rulez.field`` ``__getitem__`` method in favor of ``__call__``


0.1.3 (2020-11-12)
------------------

- Added documentation
- Improved DSL parsing
- Enhance ``rulez.field`` with more operations
